@@ -52,7 +52,6 @@ import (
 	"knative.dev/pkg/controller"
 	"knative.dev/pkg/kmeta"
 	"knative.dev/pkg/logging"
-	logtesting "knative.dev/pkg/logging/testing"
 	"knative.dev/pkg/metrics"
 	_ "knative.dev/pkg/metrics/testing"
 	"knative.dev/pkg/system"
@@ -520,7 +519,6 @@ func getPodAnnotationsForConfig(t *testing.T, configMapValue string, configAnnot
 }
 
 func TestGlobalResyncOnConfigMapUpdateRevision(t *testing.T) {
-	defer logtesting.ClearAll()
 	// Test that changes to the ConfigMap result in the desired changes on an existing
 	// revision.
 	tests := []struct {
@@ -563,12 +561,6 @@ func TestGlobalResyncOnConfigMapUpdateRevision(t *testing.T) {
 
 			ctx, cancel := context.WithCancel(ctx)
 			grp := errgroup.Group{}
-			defer func() {
-				cancel()
-				if err := grp.Wait(); err != nil {
-					t.Errorf("Wait() = %v", err)
-				}
-			}()
 
 			servingClient := fakeservingclient.Get(ctx)
 
@@ -579,9 +571,18 @@ func TestGlobalResyncOnConfigMapUpdateRevision(t *testing.T) {
 
 			h.OnUpdate(&servingClient.Fake, "revisions", test.callback(t))
 
-			if err := controller.StartInformers(ctx.Done(), informers...); err != nil {
+			waitInformers, err := controller.RunInformers(ctx.Done(), informers...)
+			if err != nil {
 				t.Fatalf("Failed to start informers: %v", err)
 			}
+			defer func() {
+				cancel()
+				if err := grp.Wait(); err != nil {
+					t.Errorf("Wait() = %v", err)
+				}
+				waitInformers()
+			}()
+
 			if err := watcher.Start(ctx.Done()); err != nil {
 				t.Fatalf("Failed to start configuration manager: %v", err)
 			}
@@ -600,7 +601,6 @@ func TestGlobalResyncOnConfigMapUpdateRevision(t *testing.T) {
 }
 
 func TestGlobalResyncOnConfigMapUpdateDeployment(t *testing.T) {
-	defer logtesting.ClearAll()
 	// Test that changes to the ConfigMap result in the desired changes on an existing
 	// deployment.
 	tests := []struct {
@@ -717,12 +717,6 @@ func TestGlobalResyncOnConfigMapUpdateDeployment(t *testing.T) {
 
 			ctx, cancel := context.WithCancel(ctx)
 			grp := errgroup.Group{}
-			defer func() {
-				cancel()
-				if err := grp.Wait(); err != nil {
-					t.Errorf("Wait() = %v", err)
-				}
-			}()
 
 			kubeClient := fakekubeclient.Get(ctx)
 
@@ -738,9 +732,18 @@ func TestGlobalResyncOnConfigMapUpdateDeployment(t *testing.T) {
 				return HookComplete
 			})
 
-			if err := controller.StartInformers(ctx.Done(), informers...); err != nil {
+			waitInformers, err := controller.RunInformers(ctx.Done(), informers...)
+			if err != nil {
 				t.Fatalf("Failed to start informers: %v", err)
 			}
+			defer func() {
+				cancel()
+				if err := grp.Wait(); err != nil {
+					t.Errorf("Wait() = %v", err)
+				}
+				waitInformers()
+			}()
+
 			if err := watcher.Start(ctx.Done()); err != nil {
 				t.Fatalf("Failed to start configuration manager: %v", err)
 			}
