@@ -21,7 +21,7 @@ import (
 	"fmt"
 	"net/http"
 
-	"github.com/knative/serving/test"
+	"knative.dev/serving/test"
 )
 
 func handler(w http.ResponseWriter, r *http.Request) {
